@@ -1,6 +1,5 @@
 #' Generate numeric XPath expression
 #'
-#' @title num_xpath: Generate numeric XPath expression
 #' @param data the header XPath
 #' @export
 num_xpath <- function(data) UseMethod("num_xpath")
@@ -35,13 +34,13 @@ num_xpath.list <- function(data){
 }
 
 
-#' Return trindex given an XPath
+#' Return table row index given an XPath
 #' @param table.Node the table node
 #' @param xpath XPath
 get_trindex <- function(xpath, table.Node) UseMethod("get_trindex")
 
 get_trindex.default <- function(xpath, table.Node){
-  stop("Unknow XPath", call. = FALSE)
+  stop("Unknown XPath", call. = FALSE)
 }
 
 get_trindex.NULL <- function(xpath, table.Node){
@@ -68,7 +67,7 @@ get_trindex.list <- function(xpath, table.Node){
   return(tr.index)
 }
 
-#' Return header xpath
+#' Return header XPath
 #'
 #' @param table.Node the table node
 #' @param header an information for the header rows
@@ -117,13 +116,13 @@ get_head_xpath.NULL <- function(header, table.Node){
 
   if (!thead && !th){
     header.xpath <- "//tr[position() = 1]"
-    message("Neither <thead> nor <th> information found. Taking first table row for the header. If incorrect, specifiy header argument.")
+    message("Neither <thead> nor <th> information found. Taking first table row for the header. If incorrect, specify header argument.")
     return(c(header.xpath))
   }
 }
 
 
-#' Return body xpath
+#' Return body XPath
 #'
 #' @param table.Node the table node
 #' @param body an information for the body rows
@@ -131,7 +130,7 @@ get_head_xpath.NULL <- function(header, table.Node){
 get_body_xpath <- function(body, table.Node) UseMethod("get_body_xpath")
 
 get_body_xpath.default <- function(body, table.Node){
-  stop("Unknow body information", .call = F)
+  stop("Unknown body information", .call = F)
 }
 
 get_body_xpath.numeric <- function(body, table.Node){
