@@ -4,14 +4,16 @@
 #'   (by XML's parsing functions)
 #' @param which a vector of length one for identification of the table in the document. Either
 #'    a numeric vector for the tables' rank or a character vector that describes an XPath for the table
-#' @param ... additional arguments passed to htmlParse
+#' @param ... additional arguments passed to `htmlParse()`
 #' @return a table node
 check_type <- function(doc, which, ...) UseMethod("check_type")
 
+#' @export
 check_type.default <- function(doc, which, ...){
   stop("doc is of unknown type", call. = FALSE)
 }
 
+#' @export
 check_type.XMLNodeSet <- function(doc, which, ...){
 
   Node <- eval.parent(substitute(XML::xmlParse(XML::saveXML(doc[[1]]), list(...))))
@@ -19,6 +21,7 @@ check_type.XMLNodeSet <- function(doc, which, ...){
   return(Node)
 }
 
+#' @export
 check_type.HTMLInternalDocument <- function(doc, which, ...) {
   Node <- doc
   Node <- select_tab(which = which, Node = Node)
@@ -26,6 +29,7 @@ check_type.HTMLInternalDocument <- function(doc, which, ...) {
   return(Node)
 }
 
+#' @export
 check_type.XMLInternalElementNode <- function(doc, which, ...) {
   Node <- doc
   Node <- select_tab(which = which, Node = Node)
@@ -33,6 +37,7 @@ check_type.XMLInternalElementNode <- function(doc, which, ...) {
   return(Node)
 }
 
+#' @export
 check_type.character <- function(doc, which, ...){
 
   isurl <- is_url(doc)
@@ -44,7 +49,11 @@ check_type.character <- function(doc, which, ...){
     doc <- readChar(doc, file.info(doc)$size)
   }
 
-  Node <- eval.parent(substitute(XML::htmlParse(doc, encoding = "UTF-8", list(...))))
+  params <- list(...)
+  if (is.null(params$encoding)) {
+    params$encoding <- "UTF-8"
+  }
+  Node <- eval.parent(substitute(XML::htmlParse(doc, params)))
   Node <- select_tab(which = which, Node = Node)
 
   return(Node)
@@ -56,7 +65,6 @@ check_type.character <- function(doc, which, ...){
 #' @param Node the table node
 #' @param which a vector of length one for identification of the table in the document. Either
 #'    a numeric vector for the tables' rank or a character vector that describes an XPath for the table
-#' @param ... additional arguments passed to htmlParse
 #' @return a table node
 select_tab <- function(which, Node) UseMethod("select_tab")
 
@@ -77,7 +85,7 @@ select_tab.numeric <- function(which, Node){
   Node <- XML::getNodeSet(Node, path = "//table")
 
   ifstop(cond = length(Node) < which,
-         mess = "Couldn't find the table. Try passing (a different) information to the which argument.")
+         mess = "Couldn't find the table. Try passing (different) information to the which argument.")
 
   Node <- XML::xmlParse(XML::saveXML(Node[[which]]))
   return(Node)
@@ -89,7 +97,7 @@ select_tab.character <- function(which, Node){
   Node <- XML::getNodeSet(Node, path = xpath)
 
   ifstop(cond = is.null(Node[[1]]),
-         mess = "Couldn't find the table. Try passing (a different) information to the which argument.")
+         mess = "Couldn't find the table. Try passing (different) information to the which argument.")
 
   Node <- XML::xmlParse(XML::saveXML(Node[[1]]))
   return(Node)
@@ -111,7 +119,7 @@ eval_header <- function(arg){
 
   # Check that inbody information are complete
   ifstop(cond = any(header[-1] == "NULL"),
-         mess = "You need to provide complete information for the inbody rows")
+         mess = "You need to provide complete information for the inbody rows.")
 
   # Evaluate header information
   header <- lapply(header, function(x) eval(parse(text = x)))
@@ -129,7 +137,7 @@ eval_body <- function(arg){
   body[those.body] <- "NULL"
 
   ifstop(cond = length(body) > 1,
-         mess = "Your body information is malformed. You may only provide one piece of information")
+         mess = "Your body information is malformed. You may only provide one piece of information.")
 
   # Evaluate header information
   body <- eval(parse(text = body))
@@ -259,7 +267,7 @@ rm_empty_cols <- function(df, header){
   })
 
   empty.cols <- which(empty.cols > 0.5)
-  if(length(empty.cols) > 0) warning(sprintf("Columns [%s] seem to have no data and are removed. Use rm_nodata_cols = F to suppress this behavior", paste(names(empty.cols), collapse = ",")), call. =  F)
+  if(length(empty.cols) > 0) warning(sprintf("Columns [%s] seem to have no data and are removed. Use rm_nodata_cols = F to suppress this behavior.", paste(names(empty.cols), collapse = ",")), call. =  F)
   rm.these <- empty.cols #intersect(empty.cols, no.col.name)
 
   if(length(rm.these) > 0) {
